@@ -179,12 +179,6 @@ struct passwd *pw;
 int	waitsync_fd_to_close = -1;	/* -w/--wait-sync */
 #endif
 
-/*
- * Initializing flag.  All async routines watch this and only do their
- * thing when it is clear.
- */
-int initializing;
-
 /*
  * Version declaration
  */
