@@ -4,10 +4,15 @@
 #include "timevalops.h"
 
 #include "unity.h"
-#include <math.h>// Required on Solaris for ldexp.
 
+#include <math.h> // Required on Solaris for ldexp.
 
-void test_Seconds(void)
+void test_Seconds(void);
+void test_MicrosecondsRounded(void);
+void test_MicrosecondsExact(void);
+
+void
+test_Seconds(void)
 {
 	struct timeval input = {500, 0}; // 500.0 s
 	l_fp expected = {500, 0};
@@ -18,7 +23,9 @@ void test_Seconds(void)
 	TEST_ASSERT_TRUE(IsEqual(expected, actual));
 }
 
-void test_MicrosecondsRounded(void)
+
+void
+test_MicrosecondsRounded(void)
 {
 	/* 0.0005 can not be represented exact in a l_fp structure.
 	 * It would equal to 2147483,648. This means that
@@ -30,10 +37,13 @@ void test_MicrosecondsRounded(void)
 	l_fp actual;
 
 	TVTOTS(&input, &actual);
+
 	TEST_ASSERT_TRUE(IsEqual(expected, actual));
 }
 
-void test_MicrosecondsExact(void)
+
+void
+test_MicrosecondsExact(void)
 {
 	// 0.5 can be represented exact in both l_fp and timeval.
 	const struct timeval input = {10, 500000}; // 0.5 exact
@@ -50,5 +60,5 @@ void test_MicrosecondsExact(void)
 	M_LFPTOD(0, actual.l_uf, actualDouble);
 
 	// The error should be less than 0.5 us
-	TEST_ASSERT_DOUBLE_WITHIN(0000005, expectedDouble, actualDouble);
+	TEST_ASSERT_DOUBLE_WITHIN(0.0000005, expectedDouble, actualDouble);
 }
